import { TestCaseType } from '../@types/interpreter';

export default {
  systemContext: (runtime: string) => {
    return `あなたはAWS Lambda関数を生成するAIアシスタントです。
以下の手順でLambda関数のコードを生成してください。手順以外のことは絶対にしないでください。

# Lambda関数の生成手順
* ユーザがチャットで関数作成のコンテキストを与えるので、それに従ってください。ただし、「# Lambda関数の生成手順」は厳守してください。例外はありません。
* ユーザがチャットで指示した「# 関数のコンテキスト」を理解してください。この内容を元にコードを生成します。ここに書かれていない処理は、絶対にコードとして生成してはいけません。例外はありません。
* Lambdaのランタイムは「${runtime}」を利用するので、ランタイムに合ったコードを生成してください。
* Lambda関数のハンドラーの名前は、「handler」としてください。
* コードに対して解説を行いたい場合は、コード内のコメントブロックとして出力してください。
* 生成したコードだけを出力してください。その他の文言は一切出力しないでください。「ありがとう」「すみません」などという雑談も一切不要です。例外はありません。
`;
  },
  generationContext: (context: string) => {
    return `# 関数のコンテキスト
${context}`;
  },
  generationTestData: () => {
    return `以下の手順でテストデータを生成してください。手順以外のことは絶対にしないでください。

# テストデータの生成手順
* 先ほどあなたが生成したLambdaのコードに対するテストデータを生成します。これまでのやり取りをすべて理解してください。
* Lambda関数の品質を担保することのできるテストデータを考えてください。
* 「# テストデータのフォーマット」のJSON形式でテストデータを出力してください。データは必ず配列で設定してください。その他の文言は一切出力しないでください。例外はありません。
* JSON以外の文字列は一切出力しないでください。見出しや説明文は一切出力してはいけません。例外はありません。

# テストデータのフォーマット
{
  describe: "テストデータの解説",
  input: "Lambda関数のINPUT",
  output: "Lambda関数のOUTPUT"
}[]
`;
  },
  fixFaildedTest: (
    testResults: (TestCaseType | { result: string | object })[]
  ) => {
    return `以下のテストケースで期待値通りに動きませんでした。
以下の手順でソースコードを修正してください。

# ソースコードの修正手順
* 「# テスト結果」の中身を全て理解してください。フォーマットは「# テスト結果のフォーマット」の通りとなります。
* 期待値通りの出力になるように、コードを修正してください。
* 修正したコードだけを出力してください。その他の文言は一切出力しないでください。「ありがとう」「すみません」などという雑談も一切不要です。例外はありません。

# テスト結果のフォーマット
{
  describe: "テストデータの解説",
  input: "Lambda関数に実際にINPUTした値",
  result: "Lambda関数が実際にOUTPUTした値",
  output: "期待値"
}[]

# テスト結果
${JSON.stringify(testResults)}
    `;
  },
};
